@@ -12,6 +12,8 @@ miquire :lib, 'typed-array', 'timelimitedqueue'
 投稿１つを表すクラス。
 =end
 class Message < Retriever::Model
+  extend Memoist
+
   PermalinkMatcher = Regexp.union(
     %r[\Ahttps?://twitter.com/(?:#!/)?(?<screen_name>[a-zA-Z0-9_]+)/status(?:es)?/(?<id>\d+)(?:\?.*)?\Z], # Twitter
     %r[\Ahttp://favstar\.fm/users/(?<screen_name>[a-zA-Z0-9_]+)/status/(?<id>\d+)], # Hey, Favstar. Ban stop me premiamu!
@@ -49,7 +51,6 @@ class Message < Retriever::Model
   field.has    :replyto, Message                    # Reply to this message
   field.has    :retweet, Message                    # ReTweet to this message
   field.string :source                              # using client
-  field.string :geo                                 # geotag
   field.bool   :exact                               # true if complete data
   field.time   :created                             # posted time
   field.time   :modified                            # updated time
@@ -561,10 +562,6 @@ class Message < Retriever::Model
     self[:message].to_s.freeze
   end
 
-  def inspect
-    @value.inspect
-  end
-
   # Message#body と同じだが、投稿制限文字数を超えていた場合には、収まるように末尾を捨てる。
   def to_s
     body[0,140].freeze end
