@@ -97,7 +97,7 @@ module Gtk
 
     def widget_send
       return @send if defined?(@send)
-      @send = Gtk::Button.new.add(Gtk::WebIcon.new(Skin.get('post.png'), 16, 16))
+      @send = Gtk::Button.new.add(Gtk::WebIcon.new(Skin.get_path('post.png'), 16, 16))
       @send.sensitive = postable?
       @send.signal_connect('clicked'){|button|
         post_it
@@ -106,7 +106,7 @@ module Gtk
 
     def widget_tool
       return @tool if defined?(@tool)
-      @tool = Gtk::Button.new.add(Gtk::WebIcon.new(Skin.get('close.png'), 16, 16))
+      @tool = Gtk::Button.new.add(Gtk::WebIcon.new(Skin.get_path('close.png'), 16, 16))
       @tool.signal_connect_after('focus_out_event', &method(:focus_out_event))
       @tool.ssc('event'){
         @tool.sensitive = destructible? || posting?
@@ -187,7 +187,7 @@ module Gtk
       Gtk::TextView.new end
 
     def postable?
-      not(widget_post.buffer.text.empty?) and (/[^\s]/ === widget_post.buffer.text) end
+      not(widget_post.buffer.text.empty?) and (/[^\p{blank}]/ === widget_post.buffer.text) end
 
     # 新しいPostBoxを作り、そちらにフォーカスを回す
     # ==== Return
