@@ -2,6 +2,8 @@
 
 module Plugin::Activity
   class Activity < Retriever::Model
+    extend Memoist
+
     include Retriever::Model::MessageMixin
     include Retriever::Model::UserMixin
 
@@ -21,7 +23,7 @@ module Plugin::Activity
 
     # TLにアイコンを表示するため
     def profile_image_url
-      icon || MUI::Skin.get('activity.png')
+      icon || MUI::Skin.get_path('activity.png')
     end
 
     def plugin
