@@ -135,7 +135,7 @@ class ::Gdk::MiraclePainter
   # 表示の更新はとくにしない
   def timestamp_label
     now = Time.now.to_i
-    there = message[:created].to_i
+    there = message.created.to_i
     diff = (there - now).abs
     label = case diff
             when 0
@@ -149,7 +149,7 @@ class ::Gdk::MiraclePainter
             else
               # TRANSLATORS: Time#strftimeが食う形式。
               # こんなん設定できたら良さそうだけどDRとかどうでもいいので適当にやってね
-              message[:created].strftime(Plugin[:display_requirements]._('%Y/%m/%d'))
+              message.created.strftime(Plugin[:display_requirements]._('%Y/%m/%d'))
             end
     Pango.escape(label)end
 
@@ -178,7 +178,7 @@ class ::Gdk::MiraclePainter
     if defined?(@hl_region) and @hl_region.point_in?(x, y)
       Plugin.call(:open, message.user)
     elsif defined?(@hr_region) and @hr_region.point_in?(x, y)
-      Gtk.openurl("https://twitter.com/#{message.user.idname}/status/#{message.id}")
+      Plugin.call(:open, message)
     else
       __clicked_l7eOfD__(x, y, e)
     end
