@@ -20,6 +20,7 @@ settingsの中身は、 Plugin::Settings のインスタンスの中で実行さ
 前後関係などに影響されてウィジェットが変わる場合があるかも。
 =end
 class Plugin::Settings < Gtk::VBox
+  extend Memoist
 
   def initialize(plugin)
     type_strict plugin => Plugin
@@ -199,11 +200,13 @@ class Plugin::Settings < Gtk::VBox
   #   _:artists_ :: デザイナとかの名前。通常Twitter screen name（Array）
   #   _:documenters_ :: ドキュメントかいた人とかの名前。通常Twitter screen name（Array）
   def about(label, options={})
+    name_mapper = Hash.new{|h,k| k }
+    name_mapper[:name] = :program_name
     about = Gtk::Button.new(label)
     about.signal_connect("clicked"){
       dialog = Gtk::AboutDialog.new.show
       options.each { |key, value|
-        dialog.__send__("#{key}=", about_converter[key][value]) }
+        dialog.__send__("#{name_mapper[key]}=", about_converter[key][value]) }
       dialog.signal_connect('response') { dialog.destroy } }
     closeup about
     about end
